.. Sage documentation master file, created by sphinx-quickstart on Thu Aug 21 20:15:55 2008.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Bem-vindo ao Tutorial Sage!
===========================

Sage é um software de matemática gratuito, de código aberto, para uso
em ensino e pesquisa em álgebra, geometria, teoria de números,
criptografia, computação numérica, e áreas relacionadas. Tanto o
modelo de desenvolvimento como a tecnologia empregada no Sage se
distinguem pela forte ênfase em transparência, cooperação, e
colaboração: estamos desenvolvendo o carro, não reinventando a roda. O
objetivo maior do Sage é criar uma alternativa viável, gratuita, e de
código aberto aos programas Maple, Mathematica, Magma e MATLAB.

Este tutorial é a melhor forma de se familiarizar com o Sage em apenas
algumas horas. Você pode lê-lo em versão HTML ou PDF, ou diretamente
no Notebook Sage (clique em ``Help``, e então clique em ``Tutorial``
para percorrer o tutorial de forma iterativa diretamente do Sage).

Este documento está sob a licença `Creative Commons CompartilhaIgual
3.0`__.

__ http://creativecommons.org/licenses/by-sa/3.0/deed.pt

.. toctree::
   :maxdepth: 2

   introduction
   tour
   interactive_shell
   interfaces
   latex
   programming
   sagetex
   afterword
   appendix
   bibliography

Índices e tabelas 
=================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
